@@ -318,7 +318,7 @@ def run_ex(
 
 
 def idem_cli(
-    subcommand: str, env: Dict[str, str] = None, check: bool = True, *args
+    subcommand: str, *args, env: Dict[str, str] = None, check: bool = True
 ) -> Dict[str, Any]:
     """
     Shell out to run an idem subcommand on the cli and parse the output as json
